@@ -2,6 +2,9 @@
 $description Live TV channels from SBS, a South Korean public broadcaster.
 $url www.sbs.co.kr/live
 $type live
+$metadata id
+$metadata author
+$metadata title
 $region South Korea
 """
 
@@ -17,9 +20,9 @@ from streamlink.stream.hls import HLSStream
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(
-    r"https?://www\.sbs\.co\.kr/live/(?P<channel>[^/?]+)"
-))
+@pluginmatcher(
+    re.compile(r"https?://www\.sbs\.co\.kr/live/(?P<channel>[^/?]+)"),
+)
 @pluginargument(
     "id",
     help=argparse.SUPPRESS,
@@ -37,9 +40,11 @@ class SBScokr(Plugin):
                 schema=validate.Schema(
                     validate.parse_json(),
                     {
-                        "list": [{
-                            "channelid": str,
-                        }],
+                        "list": [
+                            {
+                                "channelid": str,
+                            },
+                        ],
                     },
                     validate.get("list"),
                     validate.map(lambda item: item["channelid"]),
