@@ -1,5 +1,6 @@
 from streamlink.stream.dash import DASHStream
-from streamlink.stream.hls import HLSStream
+from streamlink.stream.ffmpegmux import MuxedStream
+from streamlink.stream.hls import HLSStream, MuxedHLSStream
 from streamlink.stream.http import HTTPStream
 from streamlink.stream.stream import Stream, StreamIO
 from streamlink.stream.wrappers import StreamIOIterWrapper, StreamIOThreadWrapper, StreamIOWrapper
