@@ -1,15 +1,17 @@
+from __future__ import annotations
+
 import logging
 import math
 import re
 from binascii import Error as BinasciiError, unhexlify
-from datetime import datetime, timedelta
-from typing import Callable, ClassVar, Dict, Generic, Iterator, List, Mapping, Optional, Tuple, Type, TypeVar, Union
+from datetime import timedelta
+from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar
 from urllib.parse import urljoin, urlparse
 
-from isodate import ISO8601Error, parse_datetime  # type: ignore[import]
+from isodate import ISO8601Error, parse_datetime  # type: ignore[import]  # ty:ignore[unused-ignore-comment]
 from requests import Response
 
-from streamlink.logger import ALL, StreamlinkLogger
+from streamlink.logger import ALL
 from streamlink.stream.hls.segment import (
     ByteRange,
     DateRange,
@@ -26,10 +28,11 @@ from streamlink.stream.hls.segment import (
 )
 
 
-try:
-    from typing import Self  # type: ignore[attr-defined]
-except ImportError:  # pragma: no cover
-    from typing_extensions import Self
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterator, Mapping
+    from datetime import datetime
+
+    from streamlink.logger import StreamlinkLogger
 
 
 log: StreamlinkLogger = logging.getLogger(__name__)  # type: ignore[assignment]
@@ -40,29 +43,29 @@ THLSPlaylist_co = TypeVar("THLSPlaylist_co", bound=HLSPlaylist, covariant=True)
 
 
 class M3U8(Generic[THLSSegment_co, THLSPlaylist_co]):
-    def __init__(self, uri: Optional[str] = None):
+    def __init__(self, uri: str | None = None):
         self.uri = uri
 
         self.is_endlist: bool = False
         self.is_master: bool = False
 
-        self.allow_cache: Optional[bool] = None  # version < 7
-        self.discontinuity_sequence: Optional[int] = None
-        self.iframes_only: Optional[bool] = None  # version >= 4
-        self.media_sequence: Optional[int] = None
-        self.playlist_type: Optional[str] = None
-        self.targetduration: Optional[float] = None
-        self.start: Optional[Start] = None
-        self.version: Optional[int] = None
+        self.allow_cache: bool | None = None  # version < 7
+        self.discontinuity_sequence: int | None = None
+        self.iframes_only: bool | None = None  # version >= 4
+        self.media_sequence: int | None = None
+        self.playlist_type: str | None = None
+        self.targetduration: float | None = None
+        self.start: Start | None = None
+        self.version: int | None = None
 
-        self.media: List[Media] = []
-        self.dateranges: List[DateRange] = []
+        self.media: list[Media] = []
+        self.dateranges: list[DateRange] = []
 
-        self.playlists: List[THLSPlaylist_co] = []
-        self.segments: List[THLSSegment_co] = []
+        self.playlists: list[THLSPlaylist_co] = []
+        self.segments: list[THLSSegment_co] = []
 
     @classmethod
-    def is_date_in_daterange(cls, date: Optional[datetime], daterange: DateRange):
+    def is_date_in_daterange(cls, date: datetime | None, daterange: DateRange):
         if date is None or daterange.start_date is None:
             return None
 
@@ -99,7 +102,7 @@ class M3U8ParserMeta(type):
         tags = dict(**getattr(cls, "_TAGS", {}))
         for member in namespace.values():
             tag = getattr(member, _symbol_tag_parser, None)
-            if type(tag) is not str:  # noqa: E721
+            if type(tag) is not str:
                 continue
             tags[tag] = member
         cls._TAGS = tags
@@ -107,53 +110,58 @@ class M3U8ParserMeta(type):
 
 class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M3U8ParserMeta):
     # Can't set type vars as classvars yet (PEP 526 issue)
-    __m3u8__: ClassVar[Type[M3U8[HLSSegment, HLSPlaylist]]] = M3U8
-    __segment__: ClassVar[Type[HLSSegment]] = HLSSegment
-    __playlist__: ClassVar[Type[HLSPlaylist]] = HLSPlaylist
+    __m3u8__: ClassVar[type[M3U8[HLSSegment, HLSPlaylist]]] = M3U8
+    __segment__: ClassVar[type[HLSSegment]] = HLSSegment
+    __playlist__: ClassVar[type[HLSPlaylist]] = HLSPlaylist
 
-    _TAGS: ClassVar[Mapping[str, Callable[[Self, str], None]]]
+    # TODO: fix this (can't use Self in a ClassVar)
+    _TAGS: ClassVar[Mapping[str, Callable[[M3U8Parser, str], None]]]
 
     _extinf_re = re.compile(r"(?P<duration>\d+(\.\d+)?)(,(?P<title>.+))?")
-    _attr_re = re.compile(r"""
-        (?P<key>[A-Z0-9\-]+)
-        =
-        (?P<value>
-            (?# decimal-integer)
-            \d+
-            (?# hexadecimal-sequence)
-            |0[xX][0-9A-Fa-f]+
-            (?# decimal-floating-point and signed-decimal-floating-point)
-            |-?\d+\.\d+
-            (?# quoted-string)
-            |\"(?P<quoted>[^\r\n\"]*)\"
-            (?# enumerated-string)
-            |[^\",\s]+
-            (?# decimal-resolution)
-            |\d+x\d+
-        )
-        (?# be more lenient and allow spaces around attributes)
-        \s*(?:,\s*|$)
-    """, re.VERBOSE)
+    _attr_re = re.compile(
+        r"""
+            (?P<key>[A-Z0-9\-]+)
+            =
+            (?P<value>
+                (?# decimal-integer)
+                \d+
+                (?# hexadecimal-sequence)
+                |0[xX][0-9A-Fa-f]+
+                (?# decimal-floating-point and signed-decimal-floating-point)
+                |-?\d+\.\d+
+                (?# quoted-string)
+                |\"(?P<quoted>[^\r\n\"]*)\"
+                (?# enumerated-string)
+                |[^\",\s]+
+                (?# decimal-resolution)
+                |\d+x\d+
+            )
+            (?# be more lenient and allow spaces around attributes)
+            \s*(?:,\s*|$)
+        """,
+        re.VERBOSE,
+    )
     _range_re = re.compile(r"(?P<range>\d+)(?:@(?P<offset>\d+))?")
     _tag_re = re.compile(r"#(?P<tag>[\w-]+)(:(?P<value>.+))?")
     _res_re = re.compile(r"(\d+)x(\d+)")
 
-    def __init__(self, base_uri: Optional[str] = None):
-        self.m3u8: TM3U8_co = self.__m3u8__(base_uri)  # type: ignore[assignment]  # PEP 696 might solve this
+    def __init__(self, base_uri: str | None = None):
+        # PEP 696 might solve this
+        self.m3u8: TM3U8_co = self.__m3u8__(base_uri)  # type: ignore[assignment]  # ty:ignore[unused-ignore-comment]
 
         self._expect_playlist: bool = False
-        self._streaminf: Optional[Dict[str, str]] = None
+        self._streaminf: dict[str, str] | None = None
 
         self._expect_segment: bool = False
-        self._extinf: Optional[ExtInf] = None
-        self._byterange: Optional[ByteRange] = None
+        self._extinf: ExtInf | None = None
+        self._byterange: ByteRange | None = None
         self._discontinuity: bool = False
-        self._map: Optional[Map] = None
-        self._key: Optional[Key] = None
-        self._date: Optional[datetime] = None
+        self._map: Map | None = None
+        self._key: Key | None = None
+        self._date: datetime | None = None
 
     @classmethod
-    def create_stream_info(cls, streaminf: Mapping[str, Optional[str]], streaminfoclass=None):
+    def create_stream_info(cls, streaminf: Mapping[str, str | None], streaminfoclass=None):
         program_id = streaminf.get("PROGRAM-ID")
 
         try:
@@ -162,10 +170,10 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         except ValueError:
             bandwidth = 0
 
-        _resolution = streaminf.get("RESOLUTION")
-        resolution = None if not _resolution else cls.parse_resolution(_resolution)
+        res = streaminf.get("RESOLUTION")
+        resolution = None if not res else cls.parse_resolution(res)
 
-        codecs = (streaminf.get("CODECS") or "").split(",")
+        codecs = str(streaminf.get("CODECS") or "").split(",")
 
         if streaminfoclass is IFrameStreamInfo:
             return IFrameStreamInfo(
@@ -187,7 +195,7 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
             )
 
     @classmethod
-    def split_tag(cls, line: str) -> Union[Tuple[str, str], Tuple[None, None]]:
+    def split_tag(cls, line: str) -> tuple[str, str] | tuple[None, None]:
         match = cls._tag_re.match(line)
 
         if match:
@@ -196,10 +204,10 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         return None, None
 
     @classmethod
-    def parse_attributes(cls, value: str) -> Dict[str, str]:
+    def parse_attributes(cls, value: str) -> dict[str, str]:
         pos = 0
         length = len(value)
-        res: Dict[str, str] = {}
+        res: dict[str, str] = {}
         while pos < length:
             match = cls._attr_re.match(value, pos)
             if match is None:
@@ -216,14 +224,15 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         return value == "YES"
 
     @classmethod
-    def parse_byterange(cls, value: str) -> Optional[ByteRange]:
+    def parse_byterange(cls, value: str) -> ByteRange | None:
         match = cls._range_re.match(value)
         if match is None:
             return None
 
-        _range, offset = match.groups()
+        offset = match["offset"]
+
         return ByteRange(
-            range=int(_range),
+            range=int(match["range"]),
             offset=int(offset) if offset is not None else None,
         )
 
@@ -239,7 +248,7 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         )
 
     @staticmethod
-    def parse_hex(value: Optional[str]) -> Optional[bytes]:
+    def parse_hex(value: str | None) -> bytes | None:
         if value is None:
             return None
 
@@ -253,7 +262,7 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         return None
 
     @staticmethod
-    def parse_iso8601(value: Optional[str]) -> Optional[datetime]:
+    def parse_iso8601(value: str | None) -> datetime | None:
         try:
             return None if value is None else parse_datetime(value)
         except (ISO8601Error, ValueError):
@@ -261,7 +270,7 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
             return None
 
     @staticmethod
-    def parse_timedelta(value: Optional[str]) -> Optional[timedelta]:
+    def parse_timedelta(value: str | None) -> timedelta | None:
         return None if value is None else timedelta(seconds=float(value))
 
     @classmethod
@@ -353,6 +362,7 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         byterange = self.parse_byterange(attr.get("BYTERANGE", ""))
         self._map = Map(
             uri=self.uri(uri),
+            key=self._key,
             byterange=byterange,
         )
 
@@ -444,19 +454,22 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
         https://datatracker.ietf.org/doc/html/rfc8216#section-4.3.4.1
         """
         attr = self.parse_attributes(value)
-        _type = attr.get("TYPE")
+        mediatype = attr.get("TYPE")
         uri = attr.get("URI")
         group_id = attr.get("GROUP-ID")
         name = attr.get("NAME")
 
-        if not _type or not group_id or not name:
+        if not mediatype or not group_id or not name:
             return
 
+        if language := attr.get("LANGUAGE"):
+            language = language.strip().lower()
+
         media = Media(
-            type=_type,
+            type=mediatype,
             uri=self.uri(uri) if uri else None,
             group_id=group_id,
-            language=attr.get("LANGUAGE"),
+            language=language,
             name=name,
             default=self.parse_bool(attr.get("DEFAULT", "NO")),
             autoselect=self.parse_bool(attr.get("AUTOSELECT", "NO")),
@@ -559,7 +572,7 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
             playlist = self.get_playlist(self.uri(line))
             self.m3u8.playlists.append(playlist)
 
-    def parse(self, data: Union[str, Response]) -> TM3U8_co:
+    def parse(self, data: str | Response) -> TM3U8_co:
         lines: Iterator[str]
         if isinstance(data, str):
             lines = iter(filter(bool, data.splitlines()))
@@ -650,9 +663,9 @@ class M3U8Parser(Generic[TM3U8_co, THLSSegment_co, THLSPlaylist_co], metaclass=M
 
 
 def parse_m3u8(
-    data: Union[str, Response],
-    base_uri: Optional[str] = None,
-    parser: Type[M3U8Parser[TM3U8_co, THLSSegment_co, THLSPlaylist_co]] = M3U8Parser,
+    data: str | Response,
+    base_uri: str | None = None,
+    parser: type[M3U8Parser[TM3U8_co, THLSSegment_co, THLSPlaylist_co]] = M3U8Parser,
 ) -> TM3U8_co:
     """
     Parse an M3U8 playlist from a string of data or an HTTP response.
