@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import argparse
 import importlib.metadata
 import logging
 import os
@@ -11,22 +10,18 @@ import ssl
 import sys
 import warnings
 from atexit import register as _atexit_register
-from collections.abc import Mapping
 from contextlib import closing, suppress
 from gettext import gettext
 from pathlib import Path
 from time import sleep
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import streamlink.logger as logger
 from streamlink import NoPluginError, PluginError, StreamError, Streamlink, __version__ as streamlink_version
 from streamlink.exceptions import FatalPluginError, StreamlinkDeprecationWarning
-from streamlink.plugin import Plugin
-from streamlink.stream.stream import Stream, StreamIO
 from streamlink.utils.named_pipe import NamedPipe
 from streamlink.utils.times import LOCAL as LOCALTIMEZONE
 from streamlink_cli.argparser import (
-    ArgumentParser,
     build_parser,
     setup_plugin_args,
     setup_plugin_options,
@@ -51,10 +46,19 @@ from streamlink_cli.utils import Formatter, datetime
 from streamlink_cli.utils.versioncheck import check_version
 
 
+if TYPE_CHECKING:
+    import argparse
+    from collections.abc import Mapping
+
+    from streamlink.plugin import Plugin
+    from streamlink.stream.stream import Stream, StreamIO
+    from streamlink_cli.argparser import ArgumentParser
+
+
 QUIET_OPTIONS = ("json", "stream_url", "quiet")
 
 
-args: Any = None  # type: ignore[assignment]
+args: argparse.Namespace = None  # type: ignore[assignment]
 console: ConsoleOutput = None  # type: ignore[assignment]
 output: FileOutput | PlayerOutput = None  # type: ignore[assignment]
 stream_fd: StreamIO = None  # type: ignore[assignment]
@@ -82,27 +86,30 @@ def get_formatter(plugin: Plugin):
     )
 
 
-def check_file_output(path: Path, force: bool) -> Path:
+def check_file_output(path: Path, skip: bool, force: bool) -> Path:
     """
-    Checks if path already exists and asks the user if it should be overwritten if it does.
+    Checks if `path` already exists and asks the user if it should be overwritten if it does.
     """
 
-    # rewrap path and resolve using `os.path.realpath` instead of `path.resolve()`
-    # to avoid a pathlib issues on py39 and below
-    realpath = Path(os.path.realpath(path))
+    realpath = path.resolve()
 
     log.info(f"Writing output to\n{realpath}")
     log.debug("Checking file output")
 
-    if realpath.is_file() and not force:
-        try:
-            answer = console.ask(f"File {path} already exists! Overwrite it? [y/N] ")
-        except OSError:
-            log.error(f"File {path} already exists, use --force to overwrite it.")
-            raise StreamlinkCLIError() from None
-        if not answer or answer.lower() != "y":
+    if realpath.is_file():
+        if skip:
+            log.error(f"File {path} already exists")
             raise StreamlinkCLIError()
 
+        if not force:
+            try:
+                answer = console.ask(f"File {path} already exists! Overwrite it? [y/N] ")
+            except OSError:
+                log.error(f"File {path} already exists, use --force to overwrite it or --skip this prompt")
+                raise StreamlinkCLIError() from None
+            if not answer or answer.lower() != "y":
+                raise StreamlinkCLIError()
+
     return realpath
 
 
@@ -126,7 +133,7 @@ def create_output(formatter: Formatter) -> FileOutput | PlayerOutput:
         if args.output == "-":
             return FileOutput(fd=stdout)
         else:
-            filename = check_file_output(formatter.path(args.output, args.fs_safe_rules), args.force)
+            filename = check_file_output(formatter.path(args.output, args.fs_safe_rules), args.skip, args.force)
             return FileOutput(filename=filename)
 
     elif args.stdout:
@@ -136,7 +143,7 @@ def create_output(formatter: Formatter) -> FileOutput | PlayerOutput:
         if not args.record or args.record == "-":
             return FileOutput(fd=stdout)
         else:
-            filename = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.force)
+            filename = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.skip, args.force)
             return FileOutput(fd=stdout, record=FileOutput(filename=filename))
 
     elif args.record_and_pipe:
@@ -145,7 +152,7 @@ def create_output(formatter: Formatter) -> FileOutput | PlayerOutput:
             StreamlinkDeprecationWarning,
             stacklevel=1,
         )
-        filename = check_file_output(formatter.path(args.record_and_pipe, args.fs_safe_rules), args.force)
+        filename = check_file_output(formatter.path(args.record_and_pipe, args.fs_safe_rules), args.skip, args.force)
         return FileOutput(fd=stdout, record=FileOutput(filename=filename))
 
     elif args.player:
@@ -153,7 +160,7 @@ def create_output(formatter: Formatter) -> FileOutput | PlayerOutput:
 
         if args.player_fifo:
             try:
-                namedpipe = NamedPipe()  # type: ignore[abstract]  # ???
+                namedpipe = NamedPipe()
             except OSError as err:
                 raise StreamlinkCLIError(f"Failed to create pipe: {err}") from err
         elif args.player_http:
@@ -163,7 +170,7 @@ def create_output(formatter: Formatter) -> FileOutput | PlayerOutput:
             if args.record == "-":
                 record = FileOutput(fd=stdout)
             else:
-                filename = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.force)
+                filename = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.skip, args.force)
                 record = FileOutput(filename=filename)
 
         log.info(f"Starting player: {args.player}")
@@ -736,8 +743,11 @@ def setup_args(
 
     args, unknown = parser.parse_known_args(configs + arglist)
     if unknown and not ignore_unknown:
-        msg = gettext("unrecognized arguments: %s")
-        parser.error(msg % " ".join(unknown))
+        # output the same text as parser.error(), but raise a StreamlinkCLIError
+        usage = parser.format_usage()
+        msg = gettext("unrecognized arguments: %s") % " ".join(unknown)
+        error = f"{parser.prog}: error: {msg}"
+        raise StreamlinkCLIError(f"{usage}{error}", code=2)
 
     # Force lowercase to allow case-insensitive lookup
     if args.stream:
@@ -973,7 +983,10 @@ def setup(parser: ArgumentParser) -> None:
     log_current_versions()
     log_current_arguments(streamlink, parser)
 
-    setup_session_options(streamlink, args)
+    try:
+        setup_session_options(streamlink, args)
+    except Exception as err:
+        raise StreamlinkCLIError from err
 
     setup_signals()
 
@@ -1010,7 +1023,7 @@ def main():
         setup(parser)
     except StreamlinkCLIError as err:
         sys.stderr.write(f"{err}\n")
-        sys.exit(1)
+        raise SystemExit(err.code) from None
 
     try:
         exit_code = run(parser)
@@ -1026,4 +1039,4 @@ def main():
     # Prevent BrokenPipeError: unset sys.stdout, so Python doesn't attempt a flush() on exit
     del sys.stdout
 
-    sys.exit(exit_code)
+    raise SystemExit(exit_code)
