@@ -10,7 +10,7 @@ import warnings
 from contextlib import suppress
 from shutil import which
 from time import sleep
-from typing import TYPE_CHECKING, ClassVar, TextIO
+from typing import TYPE_CHECKING, ClassVar, TextIO, cast
 
 from streamlink.compat import is_win32
 from streamlink.exceptions import StreamlinkWarning
@@ -22,11 +22,6 @@ if TYPE_CHECKING:
     from collections.abc import Mapping, Sequence
     from pathlib import Path
 
-    try:
-        from typing import Self  # type: ignore[attr-defined]
-    except ImportError:  # pragma: no cover
-        from typing_extensions import Self
-
     from streamlink.utils.named_pipe import NamedPipeBase
     from streamlink_cli.output.file import FileOutput
     from streamlink_cli.output.http import HTTPOutput
@@ -36,12 +31,12 @@ log = logging.getLogger("streamlink.cli.output")
 
 
 class PlayerArgsMeta(type):
-    PLAYERS: ClassVar[list[Self]] = []
+    PLAYERS: ClassVar[list[type[PlayerArgs]]] = []
 
     def __init__(cls, name, bases, attrs, **kwargs):
         super().__init__(name, bases, attrs, **kwargs)
         if attrs.get("NAME"):
-            cls.PLAYERS.append(cls)
+            cls.PLAYERS.append(cast("type[PlayerArgs]", cls))
 
 
 class PlayerArgs(metaclass=PlayerArgsMeta):
@@ -103,6 +98,13 @@ class PlayerArgs(metaclass=PlayerArgsMeta):
         else:
             self._input = self.get_stdin()
 
+    @classmethod
+    def get_player_names(cls) -> list[str]:
+        return sorted(
+            (p.NAME for p in cls.PLAYERS),
+            key=lambda s: s.lower(),
+        )
+
     @staticmethod
     def _get_flatpak_args_app_index(args: list[str]) -> int:
         found_run_cmd = False
@@ -208,6 +210,7 @@ class PlayerOutput(Output):
     PLAYER_ARGS_INPUT = "playerinput"
     PLAYER_ARGS_TITLE = "playertitleargs"
 
+    playerargs: PlayerArgs
     player: subprocess.Popen
     stdin: int | TextIO
     stdout: int | TextIO
@@ -274,8 +277,9 @@ class PlayerOutput(Output):
         args = self.playerargs.build()
 
         playerpath = args[0]
-        args[0] = which(playerpath)
-        if not args[0]:
+        if resolved := which(playerpath):
+            args[0] = resolved
+        else:
             if playerpath[:1] in ('"', "'"):
                 warnings.warn(
                     "\n".join([
@@ -345,7 +349,7 @@ class PlayerOutput(Output):
             self.namedpipe.close()
         elif self.http:
             self.http.shutdown()
-        elif not self.filename:
+        elif not self.filename and self.player.stdin:  # pragma: no branch
             self.player.stdin.close()
 
         if self.record:
@@ -372,5 +376,5 @@ class PlayerOutput(Output):
             self.namedpipe.write(data)
         elif self.http:
             self.http.write(data)
-        else:
+        elif self.player.stdin:  # pragma: no branch
             self.player.stdin.write(data)
