@@ -16,13 +16,13 @@ __all__ = [
 
 
 class JSONEncoder(json.JSONEncoder):
-    def default(self, obj):
-        if hasattr(obj, "__json__"):
-            return obj.__json__()
-        elif isinstance(obj, bytes):
-            return obj.decode("utf8", "ignore")
+    def default(self, o):
+        if hasattr(o, "__json__"):
+            return o.__json__()
+        elif isinstance(o, bytes):
+            return o.decode("utf8", "ignore")
         else:
-            return json.JSONEncoder.default(self, obj)
+            return json.JSONEncoder.default(self, o)
 
 
 # noinspection PyPep8Naming
