@@ -2,9 +2,9 @@ from __future__ import annotations
 
 import errno
 from collections import deque
-from collections.abc import Callable
 from pathlib import Path
 from threading import Thread
+from typing import TYPE_CHECKING
 from unittest.mock import Mock, patch
 
 import pytest
@@ -16,6 +16,10 @@ from streamlink_cli.streamrunner import PlayerPollThread, StreamRunner, log as s
 from tests.testutils.handshake import Handshake
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+
 TIMEOUT_AWAIT_HANDSHAKE = 1
 TIMEOUT_AWAIT_THREADJOIN = 1
 
