@@ -136,7 +136,7 @@ def _patch_trio_run():
     # `strict_exception_groups` changed from False to True in `trio==0.25`:
     # Patch `trio.run()` and make older versions of trio behave like `trio>=0.25`
     # as pytest-trio doesn't allow setting custom `trio.run()` args/kwargs
-    trio.run = partial(trio.run, strict_exception_groups=True)
+    trio.run = partial(trio.run, strict_exception_groups=True)  # type: ignore
     yield
     trio.run = trio_run
 
