@@ -1,3 +1,5 @@
+from contextlib import nullcontext
+
 import pytest
 from lxml.etree import Element
 
@@ -7,6 +9,9 @@ from streamlink.plugin.api.validate import xml_element
 from streamlink.utils.parse import parse_html, parse_json, parse_qsd, parse_xml
 
 
+does_not_raise = nullcontext()
+
+
 class TestUtilsParse:
     def test_parse_json(self):
         assert parse_json("{}") == {}
@@ -143,33 +148,44 @@ class TestUtilsParse:
         assert tree.xpath(".//body/text()") == [expected]
 
     @pytest.mark.parametrize(
-        ("content", "expected"),
+        ("content", "expected", "raises"),
         [
             pytest.param(
                 """<?xml version="1.0" encoding="UTF-8"?><!DOCTYPE html><html><body>ä?></body></html>""",
                 "ä?>",
+                does_not_raise,
                 id="string",
             ),
             pytest.param(
                 b"""<?xml version="1.0" encoding="UTF-8"?><!DOCTYPE html><html><body>\xc3\xa4?></body></html>""",
                 "ä?>",
+                does_not_raise,
                 id="bytes-utf-8",
             ),
             pytest.param(
                 b"""<?xml version="1.0" encoding="ISO-8859-1"?><!DOCTYPE html><html><body>\xe4?></body></html>""",
                 "ä?>",
+                does_not_raise,
                 id="bytes-iso-8859-1",
             ),
+            pytest.param(
+                b"""<?xml version="1.0" encoding="\x00\xff\xff\x00"?><!DOCTYPE html><html><body>\xc3\xa4?></body></html>""",
+                "",
+                pytest.raises(PluginError, match=r"^Unable to detect encoding of HTML payload$"),
+                id="bytes-invalid",
+            ),
             pytest.param(
                 b"""<?xml version="1.0"?><!DOCTYPE html><html><body>\xc3\xa4?></body></html>""",
                 "ä?>",
+                does_not_raise,
                 id="bytes-unknown",
             ),
         ],
     )
-    def test_parse_html_xhtml5(self, content, expected):
-        tree = parse_html(content)
-        assert tree.xpath(".//body/text()") == [expected]
+    def test_parse_html_xhtml5(self, content: bytes | str, expected: str, raises: nullcontext):
+        with raises:
+            tree = parse_html(content)
+            assert tree.xpath(".//body/text()") == [expected]
 
     def test_parse_qsd(self):
         assert parse_qsd("test=1&foo=bar", schema=validate.Schema({"test": str, "foo": "bar"})) == {"test": "1", "foo": "bar"}
